@import url('https://rsms.me/inter/inter.css');
html { font-family: 'Inter', sans-serif; }
@supports (font-variation-settings: normal) {
  html { font-family: 'Inter var', sans-serif; }
}

:root {
  --bs-body-font-family: inter;
  --bs-body-font-size: 16px;
}

/* css styles */

.cell-output pre code {
  white-space: pre-wrap;
}


/* sidebar formatting */

.sidebar a.nav-link {
  font-size: 14.4px;
  font-weight: 400;
}


.sidebar-item-container .text-start {
  font-weight: 600;
  font-size: 14.4px !important;
}

.sidebar-item-text {
  /*color: rgba(60, 60, 60, 0.7);*/
  font-weight: 500;
  font-size: 14px;
  line-height: 22px;
}

.sidebar-item {
  margin-top: 0px;
}

.sidebar-item-section {
  padding-top: 16px;
}

.sidebar-section {
  padding-left: 0px !important;
}

.sidebar-item-section .sidebar-item-section {
  padding-top: 0px;
  padding-left: 10px;
}


td:first-child {
  text-wrap: nowrap;
  text-size-adjust: 100%;
}

td:first-child a {
  word-break: normal;
}


/* Example Gallery */

.gallery .gallery-card-body {
    height: 250px;
    padding-bottom: 20px;
}

.gallery .gallery-card-cta {
  font-size: 32px;
  text-align: center;
  padding: 100px 45px 45px 45px;
  width: 100%;
  background-color: rgb(248, 249, 250);
}

.gallery a {
  text-decoration: none;
}


.gallery .gallery-card-body img {
    width: 100%;
    height: 100%;
    object-fit: contain;
}

.gallery .card-header {
    font-size: 14px;
    text-decoration: none;
    text-align: center;
}

.gallery .card-header h6 {
  margin-top: 0.5rem;
}

.gallery .card-header a {
    text-decoration: none;
}

.gallery-links ul {
  list-style-type: none;
}

.gallery-links li {
  display: inline;
  margin-right: 60px;

}