{{! Quartodoc Docstring Template }}
{{summaryPlaceholder}}

{{extendedSummaryPlaceholder}}
{{#parametersExist}}

Parameters
----------
{{#args}}
{{var}} : 
    {{descriptionPlaceholder}}
{{/args}}
{{#kwargs}}
{{var}} : 
    {{descriptionPlaceholder}}, by default {{&default}}
{{/kwargs}}
{{/parametersExist}}
{{#returnsExist}}

Returns
-------
{{#returns}}
:
    {{descriptionPlaceholder}}
{{/returns}}
{{/returnsExist}}
{{#yieldsExist}}

Yields
------
{{#yields}}
:
    {{descriptionPlaceholder}}
{{/yields}}
{{/yieldsExist}}
{{#exceptionsExist}}

Raises
------
{{#exceptions}}
:
    {{descriptionPlaceholder}}
{{/exceptions}}
{{/exceptionsExist}}